==> openjdk-src-15.0.1.u9-1-x86_64.pkg.tar.zst: jdk.localedata/sun/util/resources/cldr/ext/CurrencyNames_nd.java <==
/*
 * Copyright (c) 2012, 2021, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

/*
 * COPYRIGHT AND PERMISSION NOTICE
 *
 * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
 * Distributed under the Terms of Use in 
 * http://www.unicode.org/copyright.html.
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of the Unicode data files and any associated documentation
 * (the "Data Files") or Unicode software and any associated documentation
 * (the "Software") to deal in the Data Files or Software
 * without restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, and/or sell copies of
 * the Data Files or Software, and to permit persons to whom the Data Files
 * or Software are furnished to do so, provided that
 * (a) this copyright and permission notice appear with all copies 
 * of the Data Files or Software,
 * (b) this copyright and permission notice appear in associated 
 * documentation, and
 * (c) there is clear notice in each modified Data File or in the Software
 * as well as in the documentation associated with the Data File(s) or
 * Software that the data or software has been modified.
 *
 * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
 * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
 * WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT OF THIRD PARTY RIGHTS.
 * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
 * NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
 * DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
 * DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
 * TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
 * PERFORMANCE OF THE DATA FILES OR SOFTWARE.
 *
 * Except as contained in this notice, the name of a copyright holder
 * shall not be used in advertising or otherwise to promote the sale,
 * use or other dealings in these Data Files or Software without prior
 * written authorization of the copyright holder.
 */

package sun.util.resources.cldr.ext;

import sun.util.resources.OpenListResourceBundle;

public class CurrencyNames_nd extends OpenListResourceBundle {
    @Override
    protected final Object[][] getContents() {
        final Object[][] data = new Object[][] {
            { "aed", "Dola laseArab" },
            { "aoa", "Kwanza yase Angola" },
            { "aud", "Dola yase Australia" },
            { "bhd", "Dinari yase Bhahareni" },
            { "bif", "Fulenki yase Bhurundi" },
            { "bwp", "Phula yase Botswana" },
            { "cad", "Dola yase Khanada" },
            { "cdf", "Fulenki yase Khongo" },
            { "chf", "Fulenki yase Swisi" },
            { "cny", "Yuan Renminbi yase China" },
            { "cve", "Escudo Caboverdiano" },
            { "djf", "Fulenki yase Jibhuthi" },
            { "dzd", "Dinali yase Aljeriya" },
            { "egp", "Phawundi laseGibhide" },
            { "ern", "Nakfa yase Eritrea" },
            { "etb", "Dola laseEthiopia" },
            { "eur", "Yuro" },
            { "gbp", "Phawundi yase Ngilandi" },
            { "ghc", "Sedi yase Ghana" },
            { "gmd", "Dalasi yase Gambia" },
            { "gns", "Fulenki yase Gine" },
            { "inr", "Rupi yase Indiya" },
            { "jpy", "Yeni yase Japhani" },
            { "kes", "Shilingi yase Kenya" },
            { "kmf", "Fulenki yase Khomoro" },
            { "lrd", "Dola yase Libheriya" },
            { "lsl", "Lothi yase Lesotho" },
            { "lyd", "Dinari yase Libya" },
            { "mad", "Dirham yase Morokho" },
            { "mga", "Fulenki yase Malagasi" },
            { "mro", "Ugwiya yase Moritaniya (1973\u20132017)" },
            { "mru", "Ugwiya yase Moritaniya" },
            { "mur", "Rupi yase Morishasi" },
            { "mwk", "Kwacha yase Malawi" },
            { "mzm", "Metikali yase Mozambiki" },
            { "nad", "Dola yase Namibiya" },
            { "ngn", "Nayira yase Nijeriya" },
            { "rwf", "Fulenki yase Ruwanda" },
            { "sar", "Riyal yase Saudi" },
            { "scr", "Rupi yase Seyisheli" },
            { "sdg", "Dinari yase Sudani" },
            { "sdp", "Phawundi yase Sudani" },
            { "shp", "Phawundindi laseSt Helena" },
            { "sll", "Leyoni" },
            { "sos", "Shilingi yase Somaliya" },
            { "std", "Dobra yase Sao Tome lo Principe (1977\u20132017)" },
            { "stn", "Dobra yase Sao Tome lo Principe" },
            { "szl", "Lilangeni" },
            { "tnd", "Dinari yase Tunisiya" },
            { "tzs", "Shilingi yase Tanzaniya" },
            { "ugx", "Shilingi yase Uganda" },
            { "usd", "Dola yase Amelika" },
            { "xaf", "Fulenki CFA BEAC" },
            { "xof", "Fulenki CFA BCEAO" },
            { "zar", "Randi yase Afrika ye Zanzi" },
            { "zmk", "Kwacha yase Zambiya (1968\u20132012)" },
            { "zmw", "Kwacha yase Zambiya" },
            { "zwd", "Dola yase Zimbabwe" },
        };
        return data;
    }
}

==> openjdk-src-25.0.2.u10-1-x86_64.pkg.tar.zst: jdk.localedata/sun/util/resources/cldr/ext/CurrencyNames_nd.java <==
/*
 * Copyright (c) 2012, 2026, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

/*
 * COPYRIGHT AND PERMISSION NOTICE
 *
 * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
 * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of the Unicode data files and any associated documentation
 * (the "Data Files") or Unicode software and any associated documentation
 * (the "Software") to deal in the Data Files or Software
 * without restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, and/or sell copies of
 * the Data Files or Software, and to permit persons to whom the Data Files
 * or Software are furnished to do so, provided that either
 * (a) this copyright and permission notice appear with all copies
 * of the Data Files or Software, or
 * (b) this copyright and permission notice appear in associated
 * Documentation.
 *
 * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
 * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
 * WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT OF THIRD PARTY RIGHTS.
 * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
 * NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
 * DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
 * DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
 * TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
 * PERFORMANCE OF THE DATA FILES OR SOFTWARE.
 *
 * Except as contained in this notice, the name of a copyright holder
 * shall not be used in advertising or otherwise to promote the sale,
 * use or other dealings in these Data Files or Software without prior
 * written authorization of the copyright holder.
 */

package sun.util.resources.cldr.ext;

import sun.util.resources.OpenListResourceBundle;

public class CurrencyNames_nd extends OpenListResourceBundle {
    @Override
    protected final Object[][] getContents() {
        final Object[][] data = new Object[][] {
            { "aed", "Dola laseArab" },
            { "aoa", "Kwanza yase Angola" },
            { "aud", "Dola yase Australia" },
            { "bhd", "Dinari yase Bhahareni" },
            { "bif", "Fulenki yase Bhurundi" },
            { "bwp", "Phula yase Botswana" },
            { "cad", "Dola yase Khanada" },
            { "cdf", "Fulenki yase Khongo" },
            { "chf", "Fulenki yase Swisi" },
            { "cny", "Yuan Renminbi yase China" },
            { "cve", "Escudo Caboverdiano" },
            { "djf", "Fulenki yase Jibhuthi" },
            { "dzd", "Dinali yase Aljeriya" },
            { "egp", "Phawundi laseGibhide" },
            { "ern", "Nakfa yase Eritrea" },
            { "etb", "Dola laseEthiopia" },
            { "eur", "Yuro" },
            { "gbp", "Phawundi yase Ngilandi" },
            { "ghc", "Sedi yase Ghana" },
            { "gmd", "Dalasi yase Gambia" },
            { "gns", "Fulenki yase Gine" },
            { "inr", "Rupi yase Indiya" },
            { "jpy", "Yeni yase Japhani" },
            { "kes", "Shilingi yase Kenya" },
            { "kmf", "Fulenki yase Khomoro" },
            { "lrd", "Dola yase Libheriya" },
            { "lsl", "Lothi yase Lesotho" },
            { "lyd", "Dinari yase Libya" },
            { "mad", "Dirham yase Morokho" },
            { "mga", "Fulenki yase Malagasi" },
            { "mro", "Ugwiya yase Moritaniya (1973\u20132017)" },
            { "mru", "Ugwiya yase Moritaniya" },
            { "mur", "Rupi yase Morishasi" },
            { "mwk", "Kwacha yase Malawi" },
            { "mzm", "Metikali yase Mozambiki" },
            { "nad", "Dola yase Namibiya" },
            { "ngn", "Nayira yase Nijeriya" },
            { "rwf", "Fulenki yase Ruwanda" },
            { "sar", "Riyal yase Saudi" },
            { "scr", "Rupi yase Seyisheli" },
            { "sdg", "Dinari yase Sudani" },
            { "sdp", "Phawundi yase Sudani" },
            { "shp", "Phawundindi laseSt Helena" },
            { "sle", "Leyoni" },
            { "sll", "Leyoni (1964\u20142022)" },
            { "sos", "Shilingi yase Somaliya" },
            { "std", "Dobra yase Sao Tome lo Principe (1977\u20132017)" },
            { "stn", "Dobra yase Sao Tome lo Principe" },
            { "szl", "Lilangeni" },
            { "tnd", "Dinari yase Tunisiya" },
            { "tzs", "Shilingi yase Tanzaniya" },
            { "ugx", "Shilingi yase Uganda" },
            { "usd", "Dola yase Amelika" },
            { "xaf", "Fulenki CFA BEAC" },
            { "xof", "Fulenki CFA BCEAO" },
            { "zar", "Randi yase Afrika ye Zanzi" },
            { "zmk", "Kwacha yase Zambiya (1968\u20132012)" },
            { "zmw", "Kwacha yase Zambiya" },
            { "zwd", "Dola yase Zimbabwe" },
        };
        return data;
    }
}
